public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: Giri P Mudusuru <giri.p.mudusuru@intel.com>
To: edk2-devel@lists.01.org
Cc: Jiewen Yao <jiewen.yao@intel.com>,
	Maurice Ma <maurice.ma@intel.com>,
	Satya Yarlagadda <satya.p.yarlagadda@intel.com>,
	Michael Kinney <michael.d.kinney@intel.com>
Subject: [PATCH 2/3] IntelFsp2Pkg: Fix typo and comments
Date: Mon, 29 Aug 2016 11:13:30 -0700	[thread overview]
Message-ID: <a595f871e5a9c7a61106db1e117e7fe7373c1104.1472493871.git.giri.p.mudusuru@intel.com> (raw)
In-Reply-To: <cover.1472493871.git.giri.p.mudusuru@intel.com>

Cc: Jiewen Yao <jiewen.yao@intel.com>
Cc: Maurice Ma <maurice.ma@intel.com>
Cc: Satya Yarlagadda <satya.p.yarlagadda@intel.com>
Cc: Michael Kinney <michael.d.kinney@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Giri P Mudusuru <giri.p.mudusuru@intel.com>
---
 .../Library/BaseFspCommonLib/FspCommonLib.c        | 34 +++++++++++-----------
 1 file changed, 17 insertions(+), 17 deletions(-)

diff --git a/IntelFsp2Pkg/Library/BaseFspCommonLib/FspCommonLib.c b/IntelFsp2Pkg/Library/BaseFspCommonLib/FspCommonLib.c
index 58c71f5..def55b9 100644
--- a/IntelFsp2Pkg/Library/BaseFspCommonLib/FspCommonLib.c
+++ b/IntelFsp2Pkg/Library/BaseFspCommonLib/FspCommonLib.c
@@ -58,7 +58,7 @@ typedef struct {
 /**
   This function sets the FSP global data pointer.
 
-  @param[in] FspData       Fsp global data pointer.
+  @param[in] FspData       FSP global data pointer.
 
 **/
 VOID
@@ -191,7 +191,7 @@ SetFspCoreStackPointer (
 /**
   This function sets the platform specific data pointer.
 
-  @param[in] PlatformData       Fsp platform specific data pointer.
+  @param[in] PlatformData       FSP platform specific data pointer.
 
 **/
 VOID
@@ -210,7 +210,7 @@ SetFspPlatformDataPointer (
 /**
   This function gets the platform specific data pointer.
 
-   @param[in] PlatformData       Fsp platform specific data pointer.
+   @param[in] PlatformData       FSP platform specific data pointer.
 
 **/
 VOID *
@@ -240,7 +240,7 @@ SetFspUpdDataPointer (
   FSP_GLOBAL_DATA  *FspData;
 
   //
-  // Get the Fsp Global Data Pointer
+  // Get the FSP Global Data Pointer
   //
   FspData  = GetFspGlobalDataPointer ();
 
@@ -269,9 +269,9 @@ GetFspUpdDataPointer (
 
 
 /**
-  This function sets the memory init UPD data pointer.
+  This function sets the FspMemoryInit UPD data pointer.
 
-  @param[in] MemoryInitUpdPtr   memory init UPD data pointer.
+  @param[in] MemoryInitUpdPtr   FspMemoryInit UPD data pointer.
 **/
 VOID
 EFIAPI
@@ -282,20 +282,20 @@ SetFspMemoryInitUpdDataPointer (
   FSP_GLOBAL_DATA  *FspData;
 
   //
-  // Get the Fsp Global Data Pointer
+  // Get the FSP Global Data Pointer
   //
   FspData  = GetFspGlobalDataPointer ();
 
   //
   // Set the memory init UPD pointer.
   //
   FspData->MemoryInitUpdPtr = MemoryInitUpdPtr;
 }
 
 /**
-  This function gets the memory init UPD data pointer.
+  This function gets the FspMemoryInit UPD data pointer.
 
-  @return memory init UPD data pointer.
+  @return FspMemoryInit UPD data pointer.
 **/
 VOID *
 EFIAPI
@@ -311,9 +311,9 @@ GetFspMemoryInitUpdDataPointer (
 
 
 /**
-  This function sets the silicon init UPD data pointer.
+  This function sets the FspSiliconInit UPD data pointer.
 
-  @param[in] SiliconInitUpdPtr   silicon init UPD data pointer.
+  @param[in] SiliconInitUpdPtr   FspSiliconInit UPD data pointer.
 **/
 VOID
 EFIAPI
@@ -324,20 +324,20 @@ SetFspSiliconInitUpdDataPointer (
   FSP_GLOBAL_DATA  *FspData;
 
   //
-  // Get the Fsp Global Data Pointer
+  // Get the FSP Global Data Pointer
   //
   FspData  = GetFspGlobalDataPointer ();
 
   //
   // Set the silicon init UPD data pointer.
   //
   FspData->SiliconInitUpdPtr = SiliconInitUpdPtr;
 }
 
 /**
-  This function gets the silicon init UPD data pointer.
+  This function gets the FspSiliconInit UPD data pointer.
 
-  @return silicon init UPD data pointer.
+  @return FspSiliconInit UPD data pointer.
 **/
 VOID *
 EFIAPI
@@ -528,6 +528,6 @@ FspApiReturnStatusReset (
     SetFspApiReturnStatus ((EFI_STATUS)FspResetType);
     Pei2LoaderSwitchStack ();
     DEBUG ((DEBUG_ERROR, "!!!ERROR: FSP has requested BootLoader for reset. But BootLoader has not honored the reset\n"));
-    DEBUG ((DEBUG_ERROR, "!!!ERROR: Please add support in BootLoader to honour the reset request from FSP\n"));
+    DEBUG ((DEBUG_ERROR, "!!!ERROR: Please add support in BootLoader to honor the reset request from FSP\n"));
   } while (LoopUntilReset);
 }
@@ -282,20 +282,20 @@ SetFspMemoryInitUpdDataPointer (
 
   //
-  // Set the memory init UPD pointer.
+  // Set the FspMemoryInit UPD pointer.
   //
   FspData->MemoryInitUpdPtr = MemoryInitUpdPtr;
@@ -324,20 +324,20 @@ SetFspSiliconInitUpdDataPointer (
 
   //
-  // Set the silicon init UPD data pointer.
+  // Set the FspSiliconInit UPD data pointer.
   //
   FspData->SiliconInitUpdPtr = SiliconInitUpdPtr;
-- 
2.9.0.windows.1



  parent reply	other threads:[~2016-08-29 18:13 UTC|newest]

Thread overview: 6+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
     [not found] <cover.1472493871.git.giri.p.mudusuru@intel.com>
2016-08-29 18:13 ` [PATCH 1/3] IntelFsp2Pkg: Remove pragma usage to align with UEFI Spec Giri P Mudusuru
2016-08-29 18:13 ` Giri P Mudusuru [this message]
2016-08-29 23:29   ` [PATCH 2/3] IntelFsp2Pkg: Fix typo and comments Yao, Jiewen
2016-08-29 18:14 ` [PATCH 3/3] IntelFsp2WrapperPkg: Update pragma to use push and pop Giri P Mudusuru
2016-08-29 18:45   ` Kinney, Michael D
2016-08-29 23:43     ` Mudusuru, Giri P

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=a595f871e5a9c7a61106db1e117e7fe7373c1104.1472493871.git.giri.p.mudusuru@intel.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox